==> python_203_main-0.5.tar.gz: python_203_main-0.5/setup.py <==
from setuptools import setup, find_packages

setup(
    name='python_203-main',
    version='0.5',
    packages=find_packages(),
    install_requires=[
        'absl-py>=2.1.0',
        'ace_tools>=0.0',
        'adagio==0.2.6',
        'aiohappyeyeballs==2.4.4',
        'aiohttp==3.11.11',
        'aiosignal==1.3.2',
        'altair==5.5.0',
        'anyio==4.7.0',
        'appdirs==1.4.4',
        'arch==7.2.0',
        'argon2-cffi==23.1.0',
        'argon2-cffi-bindings==21.2.0',
        'arrow==1.3.0',
        'asttokens==2.4.1',
        'astunparse==1.6.3',
        'async-lru==2.0.4',
        'attrs==24.3.0',
        'babel==2.16.0',
        'beautifulsoup4==4.12.3',
        'bleach==6.2.0',
        'blinker==1.9.0',
        'build==1.2.1',
        'CacheControl==0.14.0',
        'cachetools==5.5.0',
        'certifi==2024.2.2',
        'cffi==1.17.1',
        'charset-normalizer==3.3.2',
        'cleo==2.1.0',
        'click==8.1.8',
        'cloudpickle==3.1.0',
        'colorama==0.4.6',
        'comm==0.2.2',
        'contourpy==1.1.1',
        'coreforecast==0.0.15',
        'crashtest==0.4.1',
        'cycler==0.12.1',
        'Cython==3.0.10',
        'darts==0.32.0',
        'DatastreamPy==2.0.21',
        'dbnomics==1.2.5',
        'debugpy==1.8.1',
        'decorator==5.1.1',
        'defusedxml==0.7.1',
        'distlib==0.3.8',
        'dulwich==0.21.7',
        'et-xmlfile==1.1.0',
        'executing==2.0.1',
        'fastjsonschema==2.20.0',
        'filelock==3.15.4',
        'flatbuffers==24.12.23',
        'fonttools==4.43.1',
        'forex-python==1.8',
        'formulaic==1.0.1',
        'fqdn==1.5.1',
        'frozendict==2.4.2',
        'frozenlist==1.5.0',
        'fs==2.4.16',
        'fsspec==2024.12.0',
        'fugue==0.9.1',
        'gast==0.6.0',
        'gitdb==4.0.12',
        'GitPython==3.1.44',
        'google-pasta==0.2.0',
        'grpcio==1.68.1',
        'h11==0.14.0',
        'h5py==3.12.1',
        'holidays==0.63',
        'html5lib==1.1',
        'httpcore==1.0.7',
        'httpx==0.28.1',
        'idna==3.6',
        'importlib_metadata==8.4.0',
        'inflection==0.5.1',
        'installer==0.7.0',
        'interface-meta==1.3.0',
        'investpy==1.0.8',
        'ipykernel==6.29.4',
        'ipython==8.25.0',
        'ipywidgets==8.1.5',
        'isoduration==20.11.0',
        'jaraco.classes==3.4.0',
        'jedi==0.19.1',
        'Jinja2==3.1.5',
        'joblib==1.3.2',
        'json5==0.10.0',
        'jsonpointer==3.0.0',
        'jsonschema==4.23.0',
        'jsonschema-specifications==2024.10.1',
        'jupyter==1.1.1',
        'jupyter-console==6.6.3',
        'jupyter-events==0.11.0',
        'jupyter-lsp==2.2.5',
        'jupyter_client==8.6.2',
        'jupyter_core==5.7.2',
        'jupyter_server==2.15.0',
        'jupyter_server_terminals==0.5.3',
        'jupyterlab==4.3.4',
        'jupyterlab_pygments==0.3.0',
        'jupyterlab_server==2.27.3',
        'jupyterlab_widgets==3.0.13',
        'keras==3.7.0',
        'keyring==24.3.1',
        'kiwisolver==1.4.5',
        'libclang==18.1.1',
        'lightgbm==4.5.0',
        'lightning-utilities==0.11.9',
        'linearmodels==6.0',
        'llvmlite==0.43.0',
        'lxml==5.2.1',
        'Markdown==3.7',
        'markdown-it-py==3.0.0',
        'MarkupSafe==3.0.2',
        'matplotlib==3.8.0',
        'matplotlib-inline==0.1.7',
        'mdurl==0.1.2',
        'mistune==3.0.2',
        'ml-dtypes==0.4.1',
        'more-itertools==10.2.0',
        'mpmath==1.3.0',
        'msgpack==1.0.8',
        'multidict==6.1.0',
        'multitasking==0.0.11',
        'mypy-extensions==1.0.0',
        'namex==0.0.8',
        'narwhals==1.21.1',
        'natsort==8.2.0',
    ],
    licence='MIT',
    project_urls={
        'Source Repository' :  'https://github.com/elfadaliilyas/python_203'
    },
    entry_points={
        "console_scripts": [
            "backtest_strategies_reg=main:streamlit_interface"
        ]
    },
)

==> python_203_main-1.0.tar.gz: python_203_main-1.0/setup.py <==
from setuptools import setup, find_packages

with open("README.md", "r") as f:
    description = f.read()

setup(
    name='python_203-main',
    version='1.0',
    packages=find_packages(),
    include_package_data=True,
    install_requires=[
        'absl-py>=2.1.0',
        'ace_tools>=0.0',
        'adagio==0.2.6',
        'aiohappyeyeballs==2.4.4',
        'aiohttp==3.11.11',
        'aiosignal==1.3.2',
        'altair==5.5.0',
        'anyio==4.7.0',
        'appdirs==1.4.4',
        'arch==7.2.0',
        'argon2-cffi==23.1.0',
        'argon2-cffi-bindings==21.2.0',
        'arrow==1.3.0',
        'asttokens==2.4.1',
        'astunparse==1.6.3',
        'async-lru==2.0.4',
        'attrs==24.3.0',
        'babel==2.16.0',
        'beautifulsoup4==4.12.3',
        'bleach==6.2.0',
        'blinker==1.9.0',
        'build==1.2.1',
        'CacheControl==0.14.0',
        'cachetools==5.5.0',
        'certifi==2024.2.2',
        'cffi==1.17.1',
        'charset-normalizer==3.3.2',
        'cleo==2.1.0',
        'click==8.1.8',
        'cloudpickle==3.1.0',
        'colorama==0.4.6',
        'comm==0.2.2',
        'contourpy==1.1.1',
        'coreforecast==0.0.15',
        'crashtest==0.4.1',
        'cycler==0.12.1',
        'Cython==3.0.10',
        'darts==0.32.0',
        'DatastreamPy==2.0.21',
        'dbnomics==1.2.5',
        'debugpy==1.8.1',
        'decorator==5.1.1',
        'defusedxml==0.7.1',
        'distlib==0.3.8',
        'dulwich==0.21.7',
        'et-xmlfile==1.1.0',
        'executing==2.0.1',
        'fastjsonschema==2.20.0',
        'filelock==3.15.4',
        'flatbuffers==24.12.23',
        'fonttools==4.43.1',
        'forex-python==1.8',
        'formulaic==1.0.1',
        'fqdn==1.5.1',
        'frozendict==2.4.2',
        'frozenlist==1.5.0',
        'fs==2.4.16',
        'fsspec==2024.12.0',
        'fugue==0.9.1',
        'gast==0.6.0',
        'gitdb==4.0.12',
        'GitPython==3.1.44',
        'google-pasta==0.2.0',
        'grpcio==1.68.1',
        'h11==0.14.0',
        'h5py==3.12.1',
        'holidays==0.63',
        'html5lib==1.1',
        'httpcore==1.0.7',
        'httpx==0.28.1',
        'idna==3.6',
        'importlib_metadata==8.4.0',
        'inflection==0.5.1',
        'installer==0.7.0',
        'interface-meta==1.3.0',
        'investpy==1.0.8',
        'ipykernel==6.29.4',
        'ipython==8.25.0',
        'ipywidgets==8.1.5',
        'isoduration==20.11.0',
        'jaraco.classes==3.4.0',
        'jedi==0.19.1',
        'Jinja2==3.1.5',
        'joblib==1.3.2',
        'json5==0.10.0',
        'jsonpointer==3.0.0',
        'jsonschema==4.23.0',
        'jsonschema-specifications==2024.10.1',
        'jupyter==1.1.1',
        'jupyter-console==6.6.3',
        'jupyter-events==0.11.0',
        'jupyter-lsp==2.2.5',
        'jupyter_client==8.6.2',
        'jupyter_core==5.7.2',
        'jupyter_server==2.15.0',
        'jupyter_server_terminals==0.5.3',
        'jupyterlab==4.3.4',
        'jupyterlab_pygments==0.3.0',
        'jupyterlab_server==2.27.3',
        'jupyterlab_widgets==3.0.13',
        'keras==3.7.0',
        'keyring==24.3.1',
        'kiwisolver==1.4.5',
        'libclang==18.1.1',
        'lightgbm==4.5.0',
        'lightning-utilities==0.11.9',
        'linearmodels==6.0',
        'llvmlite==0.43.0',
        'lxml==5.2.1',
        'Markdown==3.7',
        'markdown-it-py==3.0.0',
        'MarkupSafe==3.0.2',
        'matplotlib==3.8.0',
        'matplotlib-inline==0.1.7',
        'mdurl==0.1.2',
        'mistune==3.0.2',
        'ml-dtypes==0.4.1',
        'more-itertools==10.2.0',
        'mpmath==1.3.0',
        'msgpack==1.0.8',
        'multidict==6.1.0',
        'multitasking==0.0.11',
        'mypy-extensions==1.0.0',
        'namex==0.0.8',
        'narwhals==1.21.1',
        'natsort==8.2.0',
    ],
    long_description=description,
    long_description_content_type="text/markdown",
)
